/********************************************************************************
** Form generated from reading UI file 'mainsettingswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINSETTINGSWIDGET_H
#define UI_MAINSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MainSettingsWidget
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox1;
    QVBoxLayout *vboxLayout1;
    QLabel *textLabel1_2;
    QComboBox *kcfg_hintHideTime;
    QLabel *textLabelResolveTime;
    QComboBox *kcfg_resolveTime;
    QGroupBox *groupBox3;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1;
    QComboBox *languageComboBox;
    QGroupBox *groupBox4;
    QVBoxLayout *vboxLayout3;
    QLabel *textLabelScoreTime;
    QComboBox *kcfg_scoreTime;
    QCheckBox *scoringPointCheckbox;
    QLabel *textCorrectAnswer;
    QComboBox *kcfg_correctAnswerScore;
    QLabel *textIncorrectAnswer;
    QComboBox *kcfg_incorrectAnswerScore;
    QLabel *textRevealAnswer;
    QComboBox *kcfg_revealAnswerScore;
    QLabel *textSkippedWord;
    QComboBox *kcfg_skippedWordScore;
    QCheckBox *kcfg_useSounds;
    QCheckBox *kcfg_uppercaseOnly;
    QCheckBox *kcfg_enablePronunciation;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *MainSettingsWidget)
    {
        if (MainSettingsWidget->objectName().isEmpty())
            MainSettingsWidget->setObjectName("MainSettingsWidget");
        MainSettingsWidget->resize(263, 603);
        vboxLayout = new QVBoxLayout(MainSettingsWidget);
        vboxLayout->setObjectName("vboxLayout");
        groupBox1 = new QGroupBox(MainSettingsWidget);
        groupBox1->setObjectName("groupBox1");
        vboxLayout1 = new QVBoxLayout(groupBox1);
        vboxLayout1->setObjectName("vboxLayout1");
        textLabel1_2 = new QLabel(groupBox1);
        textLabel1_2->setObjectName("textLabel1_2");

        vboxLayout1->addWidget(textLabel1_2);

        kcfg_hintHideTime = new QComboBox(groupBox1);
        kcfg_hintHideTime->addItem(QString());
        kcfg_hintHideTime->addItem(QString());
        kcfg_hintHideTime->addItem(QString());
        kcfg_hintHideTime->addItem(QString());
        kcfg_hintHideTime->addItem(QString());
        kcfg_hintHideTime->setObjectName("kcfg_hintHideTime");

        vboxLayout1->addWidget(kcfg_hintHideTime);

        textLabelResolveTime = new QLabel(groupBox1);
        textLabelResolveTime->setObjectName("textLabelResolveTime");

        vboxLayout1->addWidget(textLabelResolveTime);

        kcfg_resolveTime = new QComboBox(groupBox1);
        kcfg_resolveTime->addItem(QString());
        kcfg_resolveTime->addItem(QString());
        kcfg_resolveTime->addItem(QString());
        kcfg_resolveTime->addItem(QString());
        kcfg_resolveTime->addItem(QString());
        kcfg_resolveTime->setObjectName("kcfg_resolveTime");

        vboxLayout1->addWidget(kcfg_resolveTime);


        vboxLayout->addWidget(groupBox1);

        groupBox3 = new QGroupBox(MainSettingsWidget);
        groupBox3->setObjectName("groupBox3");
        vboxLayout2 = new QVBoxLayout(groupBox3);
        vboxLayout2->setObjectName("vboxLayout2");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        textLabel1 = new QLabel(groupBox3);
        textLabel1->setObjectName("textLabel1");

        hboxLayout->addWidget(textLabel1);

        languageComboBox = new QComboBox(groupBox3);
        languageComboBox->setObjectName("languageComboBox");

        hboxLayout->addWidget(languageComboBox);


        vboxLayout2->addLayout(hboxLayout);


        vboxLayout->addWidget(groupBox3);

        groupBox4 = new QGroupBox(MainSettingsWidget);
        groupBox4->setObjectName("groupBox4");
        vboxLayout3 = new QVBoxLayout(groupBox4);
        vboxLayout3->setObjectName("vboxLayout3");
        textLabelScoreTime = new QLabel(groupBox4);
        textLabelScoreTime->setObjectName("textLabelScoreTime");

        vboxLayout3->addWidget(textLabelScoreTime);

        kcfg_scoreTime = new QComboBox(groupBox4);
        kcfg_scoreTime->addItem(QString());
        kcfg_scoreTime->addItem(QString());
        kcfg_scoreTime->addItem(QString());
        kcfg_scoreTime->addItem(QString());
        kcfg_scoreTime->setObjectName("kcfg_scoreTime");

        vboxLayout3->addWidget(kcfg_scoreTime);

        scoringPointCheckbox = new QCheckBox(groupBox4);
        scoringPointCheckbox->setObjectName("scoringPointCheckbox");

        vboxLayout3->addWidget(scoringPointCheckbox);

        textCorrectAnswer = new QLabel(groupBox4);
        textCorrectAnswer->setObjectName("textCorrectAnswer");

        vboxLayout3->addWidget(textCorrectAnswer);

        kcfg_correctAnswerScore = new QComboBox(groupBox4);
        kcfg_correctAnswerScore->addItem(QString());
        kcfg_correctAnswerScore->addItem(QString());
        kcfg_correctAnswerScore->addItem(QString());
        kcfg_correctAnswerScore->addItem(QString());
        kcfg_correctAnswerScore->setObjectName("kcfg_correctAnswerScore");

        vboxLayout3->addWidget(kcfg_correctAnswerScore);

        textIncorrectAnswer = new QLabel(groupBox4);
        textIncorrectAnswer->setObjectName("textIncorrectAnswer");

        vboxLayout3->addWidget(textIncorrectAnswer);

        kcfg_incorrectAnswerScore = new QComboBox(groupBox4);
        kcfg_incorrectAnswerScore->addItem(QString());
        kcfg_incorrectAnswerScore->addItem(QString());
        kcfg_incorrectAnswerScore->addItem(QString());
        kcfg_incorrectAnswerScore->addItem(QString());
        kcfg_incorrectAnswerScore->setObjectName("kcfg_incorrectAnswerScore");

        vboxLayout3->addWidget(kcfg_incorrectAnswerScore);

        textRevealAnswer = new QLabel(groupBox4);
        textRevealAnswer->setObjectName("textRevealAnswer");

        vboxLayout3->addWidget(textRevealAnswer);

        kcfg_revealAnswerScore = new QComboBox(groupBox4);
        kcfg_revealAnswerScore->addItem(QString());
        kcfg_revealAnswerScore->addItem(QString());
        kcfg_revealAnswerScore->addItem(QString());
        kcfg_revealAnswerScore->addItem(QString());
        kcfg_revealAnswerScore->setObjectName("kcfg_revealAnswerScore");

        vboxLayout3->addWidget(kcfg_revealAnswerScore);

        textSkippedWord = new QLabel(groupBox4);
        textSkippedWord->setObjectName("textSkippedWord");

        vboxLayout3->addWidget(textSkippedWord);

        kcfg_skippedWordScore = new QComboBox(groupBox4);
        kcfg_skippedWordScore->addItem(QString());
        kcfg_skippedWordScore->addItem(QString());
        kcfg_skippedWordScore->addItem(QString());
        kcfg_skippedWordScore->addItem(QString());
        kcfg_skippedWordScore->setObjectName("kcfg_skippedWordScore");

        vboxLayout3->addWidget(kcfg_skippedWordScore);


        vboxLayout->addWidget(groupBox4);

        kcfg_useSounds = new QCheckBox(MainSettingsWidget);
        kcfg_useSounds->setObjectName("kcfg_useSounds");

        vboxLayout->addWidget(kcfg_useSounds);

        kcfg_uppercaseOnly = new QCheckBox(MainSettingsWidget);
        kcfg_uppercaseOnly->setObjectName("kcfg_uppercaseOnly");

        vboxLayout->addWidget(kcfg_uppercaseOnly);

        kcfg_enablePronunciation = new QCheckBox(MainSettingsWidget);
        kcfg_enablePronunciation->setObjectName("kcfg_enablePronunciation");

        vboxLayout->addWidget(kcfg_enablePronunciation);

        spacerItem = new QSpacerItem(16, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        textLabel1->setBuddy(languageComboBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_hintHideTime, kcfg_useSounds);
        QWidget::setTabOrder(kcfg_useSounds, kcfg_uppercaseOnly);
        QWidget::setTabOrder(kcfg_uppercaseOnly, kcfg_enablePronunciation);

        retranslateUi(MainSettingsWidget);

        QMetaObject::connectSlotsByName(MainSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *MainSettingsWidget)
    {
        MainSettingsWidget->setWindowTitle(tr2i18n("General", "@title:group main settings page name"));
#if QT_CONFIG(whatsthis)
        MainSettingsWidget->setWhatsThis(tr2i18n("This setting allows you to set the length of time Kanagram's hint bubble is shown.", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox1->setTitle(tr2i18n("Hints", nullptr));
        textLabel1_2->setText(tr2i18n("Auto-hide hints after:", nullptr));
        kcfg_hintHideTime->setItemText(0, tr2i18n("Do Not Auto-Hide Hints", nullptr));
        kcfg_hintHideTime->setItemText(1, tr2i18n("3 Seconds", nullptr));
        kcfg_hintHideTime->setItemText(2, tr2i18n("5 Seconds", nullptr));
        kcfg_hintHideTime->setItemText(3, tr2i18n("7 Seconds", nullptr));
        kcfg_hintHideTime->setItemText(4, tr2i18n("9 Seconds", nullptr));

        textLabelResolveTime->setText(tr2i18n("Time for resolving the anagram:", nullptr));
        kcfg_resolveTime->setItemText(0, tr2i18n("No time limit", nullptr));
        kcfg_resolveTime->setItemText(1, tr2i18n("15 Seconds", nullptr));
        kcfg_resolveTime->setItemText(2, tr2i18n("30 Seconds", nullptr));
        kcfg_resolveTime->setItemText(3, tr2i18n("45 Seconds", nullptr));
        kcfg_resolveTime->setItemText(4, tr2i18n("60 Seconds", nullptr));

        groupBox3->setTitle(tr2i18n("Vocabulary Options", nullptr));
        textLabel1->setText(tr2i18n("Play using:", nullptr));
        groupBox4->setTitle(tr2i18n("Scoring Options", nullptr));
        textLabelScoreTime->setText(tr2i18n("Set timer for scoring purpose:", nullptr));
        kcfg_scoreTime->setItemText(0, tr2i18n("15 Seconds", nullptr));
        kcfg_scoreTime->setItemText(1, tr2i18n("30 Seconds", nullptr));
        kcfg_scoreTime->setItemText(2, tr2i18n("45 Seconds", nullptr));
        kcfg_scoreTime->setItemText(3, tr2i18n("60 Seconds", nullptr));

        scoringPointCheckbox->setText(tr2i18n("Score Point Settings", nullptr));
        textCorrectAnswer->setText(tr2i18n("Assign score for correct answer : ", nullptr));
        kcfg_correctAnswerScore->setItemText(0, tr2i18n("+5 points", nullptr));
        kcfg_correctAnswerScore->setItemText(1, tr2i18n("+10 points", nullptr));
        kcfg_correctAnswerScore->setItemText(2, tr2i18n("+15 points", nullptr));
        kcfg_correctAnswerScore->setItemText(3, tr2i18n("+20 points", nullptr));

        textIncorrectAnswer->setText(tr2i18n("Assign score for incorrect answer : ", nullptr));
        kcfg_incorrectAnswerScore->setItemText(0, tr2i18n("-1 point", nullptr));
        kcfg_incorrectAnswerScore->setItemText(1, tr2i18n("-2 points", nullptr));
        kcfg_incorrectAnswerScore->setItemText(2, tr2i18n("-3 points", nullptr));
        kcfg_incorrectAnswerScore->setItemText(3, tr2i18n("-4 points", nullptr));

        textRevealAnswer->setText(tr2i18n("Assign score for reveal answer : ", nullptr));
        kcfg_revealAnswerScore->setItemText(0, tr2i18n("-2 points", nullptr));
        kcfg_revealAnswerScore->setItemText(1, tr2i18n("-4 points", nullptr));
        kcfg_revealAnswerScore->setItemText(2, tr2i18n("-6 points", nullptr));
        kcfg_revealAnswerScore->setItemText(3, tr2i18n("-8 points", nullptr));

        textSkippedWord->setText(tr2i18n("Assign score for skipped word : ", nullptr));
        kcfg_skippedWordScore->setItemText(0, tr2i18n("-2 points", nullptr));
        kcfg_skippedWordScore->setItemText(1, tr2i18n("-4 points", nullptr));
        kcfg_skippedWordScore->setItemText(2, tr2i18n("-6 points", nullptr));
        kcfg_skippedWordScore->setItemText(3, tr2i18n("-8 points", nullptr));

#if QT_CONFIG(whatsthis)
        kcfg_useSounds->setWhatsThis(tr2i18n("Turns sounds on/off.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_useSounds->setText(tr2i18n("Use sou&nds", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_uppercaseOnly->setWhatsThis(tr2i18n("Use only uppercase letters.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_uppercaseOnly->setText(tr2i18n("Only uppercase letters", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_enablePronunciation->setWhatsThis(tr2i18n("Turn pronunciations on or off.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_enablePronunciation->setText(tr2i18n("Say correct words", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MainSettingsWidget: public Ui_MainSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MAINSETTINGSWIDGET_H

