/********************************************************************************
** Form generated from reading UI file 'vocabsettingswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VOCABSETTINGSWIDGET_H
#define UI_VOCABSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KNSWidgets/Button"

QT_BEGIN_NAMESPACE

class Ui_VocabSettingsWidget
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *VocabVBox;
    QHBoxLayout *VocabHBox;
    QPushButton *btnCreateNew;
    KNSWidgets::Button *btnDownloadNew;
    QPushButton *btnEdit;
    QTreeWidget *lviewVocab;

    void setupUi(QWidget *VocabSettingsWidget)
    {
        if (VocabSettingsWidget->objectName().isEmpty())
            VocabSettingsWidget->setObjectName("VocabSettingsWidget");
        VocabSettingsWidget->resize(603, 408);
        VocabSettingsWidget->setMinimumSize(QSize(0, 0));
        gridLayout = new QGridLayout(VocabSettingsWidget);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        VocabVBox = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        VocabVBox->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        VocabVBox->setContentsMargins(0, 0, 0, 0);
#endif
        VocabVBox->setObjectName("VocabVBox");
        VocabHBox = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        VocabHBox->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        VocabHBox->setContentsMargins(0, 0, 0, 0);
#endif
        VocabHBox->setObjectName("VocabHBox");
        btnCreateNew = new QPushButton(VocabSettingsWidget);
        btnCreateNew->setObjectName("btnCreateNew");

        VocabHBox->addWidget(btnCreateNew);

        btnDownloadNew = new KNSWidgets::Button(VocabSettingsWidget);
        btnDownloadNew->setObjectName("btnDownloadNew");

        VocabHBox->addWidget(btnDownloadNew);


        VocabVBox->addLayout(VocabHBox);

        btnEdit = new QPushButton(VocabSettingsWidget);
        btnEdit->setObjectName("btnEdit");
        btnEdit->setEnabled(false);

        VocabVBox->addWidget(btnEdit);

        lviewVocab = new QTreeWidget(VocabSettingsWidget);
        lviewVocab->setObjectName("lviewVocab");
        lviewVocab->setRootIsDecorated(false);

        VocabVBox->addWidget(lviewVocab);


        gridLayout->addLayout(VocabVBox, 0, 0, 1, 1);


        retranslateUi(VocabSettingsWidget);

        QMetaObject::connectSlotsByName(VocabSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *VocabSettingsWidget)
    {
        VocabSettingsWidget->setWindowTitle(tr2i18n("Vocabularies", nullptr));
#if QT_CONFIG(whatsthis)
        btnCreateNew->setWhatsThis(tr2i18n("Creates a new vocabulary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btnCreateNew->setText(tr2i18n("Create &New", nullptr));
#if QT_CONFIG(tooltip)
        btnDownloadNew->setToolTip(tr2i18n("Download new vocabulary from \"Get hot new Stuff\"", nullptr));
#endif // QT_CONFIG(tooltip)
        btnDownloadNew->setText(tr2i18n("Download new vocabulary", nullptr));
#if QT_CONFIG(whatsthis)
        btnEdit->setWhatsThis(tr2i18n("Edits the selected vocabulary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btnEdit->setText(tr2i18n("&Edit", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = lviewVocab->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Description", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Title", nullptr));
#if QT_CONFIG(whatsthis)
        lviewVocab->setWhatsThis(tr2i18n("The list of installed vocabularies.", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class VocabSettingsWidget: public Ui_VocabSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VOCABSETTINGSWIDGET_H

