/****************************************************************************
** Meta object code from reading C++ file 'kanagramgame.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kanagram-26.04.2/src/kanagramgame.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kanagramgame.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KanagramGameE_t {};
} // unnamed namespace

template <> constexpr inline auto KanagramGame::qt_create_metaobjectdata<qt_meta_tag_ZN12KanagramGameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KanagramGame",
        "fileError",
        "",
        "filename",
        "dataLanguageChanged",
        "currentPlayerChanged",
        "singlePlayerChanged",
        "titleChanged",
        "wordChanged",
        "scoreChanged",
        "userAnswerChanged",
        "useSoundsChanged",
        "setSinglePlayerMode",
        "getPlayerNumber",
        "setPlayerNumber",
        "useVocabulary",
        "vocabularyname",
        "index",
        "setDataLanguage",
        "dataLanguage",
        "refreshVocabularyList",
        "loadDefaultVocabulary",
        "nextAnagram",
        "nextVocabulary",
        "previousVocabulary",
        "wordRevealed",
        "resetTotalScore",
        "adjustScore",
        "points",
        "revealWord",
        "reloadSettings",
        "answerCorrect",
        "answerIncorrect",
        "answerSkipped",
        "answerRevealed",
        "hintHideTime",
        "resolveTime",
        "scoreTime",
        "moveLetterToUserAnswer",
        "position",
        "moveLetterToAnagram",
        "resetAnagram",
        "moveLetter",
        "letter",
        "singlePlayerMode",
        "checkWord",
        "anagram",
        "word",
        "hint",
        "picHint",
        "QUrl",
        "audio",
        "userAnswer",
        "title",
        "vocabularies",
        "languages",
        "currentPlayer",
        "singlePlayer",
        "score",
        "score2",
        "useSounds"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fileError'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'dataLanguageChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentPlayerChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'singlePlayerChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wordChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scoreChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userAnswerChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useSoundsChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSinglePlayerMode'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'getPlayerNumber'
        QtMocHelpers::SlotData<int()>(13, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setPlayerNumber'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'useVocabulary'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'useVocabulary'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'setDataLanguage'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'refreshVocabularyList'
        QtMocHelpers::SlotData<bool()>(20, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'loadDefaultVocabulary'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'nextAnagram'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'nextVocabulary'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'previousVocabulary'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'wordRevealed'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetTotalScore'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'adjustScore'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'revealWord'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadSettings'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'answerCorrect'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'answerIncorrect'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'answerSkipped'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'answerRevealed'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'hintHideTime'
        QtMocHelpers::MethodData<int()>(35, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'resolveTime'
        QtMocHelpers::MethodData<int()>(36, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'scoreTime'
        QtMocHelpers::MethodData<int()>(37, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'moveLetterToUserAnswer'
        QtMocHelpers::MethodData<void(int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Method 'moveLetterToAnagram'
        QtMocHelpers::MethodData<void(int)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Method 'resetAnagram'
        QtMocHelpers::MethodData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'moveLetter'
        QtMocHelpers::MethodData<void(const QString &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 43 },
        }}),
        // Method 'singlePlayerMode'
        QtMocHelpers::MethodData<bool()>(44, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'checkWord'
        QtMocHelpers::MethodData<bool()>(45, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'anagram'
        QtMocHelpers::PropertyData<QStringList>(46, QMetaType::QStringList, QMC::DefaultPropertyFlags, 5),
        // property 'word'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'hint'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'picHint'
        QtMocHelpers::PropertyData<QUrl>(49, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'audio'
        QtMocHelpers::PropertyData<QUrl>(51, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'userAnswer'
        QtMocHelpers::PropertyData<QStringList>(52, QMetaType::QStringList, QMC::DefaultPropertyFlags, 7),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(53, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'vocabularies'
        QtMocHelpers::PropertyData<QStringList>(54, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'languages'
        QtMocHelpers::PropertyData<QStringList>(55, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'dataLanguage'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'currentPlayer'
        QtMocHelpers::PropertyData<int>(56, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'singlePlayer'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'score'
        QtMocHelpers::PropertyData<int>(58, QMetaType::Int, QMC::DefaultPropertyFlags, 6),
        // property 'score2'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags, 6),
        // property 'useSounds'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KanagramGame, qt_meta_tag_ZN12KanagramGameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KanagramGame::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KanagramGameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KanagramGameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KanagramGameE_t>.metaTypes,
    nullptr
} };

void KanagramGame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KanagramGame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fileError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->dataLanguageChanged(); break;
        case 2: _t->currentPlayerChanged(); break;
        case 3: _t->singlePlayerChanged(); break;
        case 4: _t->titleChanged(); break;
        case 5: _t->wordChanged(); break;
        case 6: _t->scoreChanged(); break;
        case 7: _t->userAnswerChanged(); break;
        case 8: _t->useSoundsChanged(); break;
        case 9: _t->setSinglePlayerMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: { int _r = _t->getPlayerNumber();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->setPlayerNumber((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->useVocabulary((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->useVocabulary((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setDataLanguage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: { bool _r = _t->refreshVocabularyList();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->loadDefaultVocabulary(); break;
        case 17: _t->nextAnagram(); break;
        case 18: _t->nextVocabulary(); break;
        case 19: _t->previousVocabulary(); break;
        case 20: _t->wordRevealed(); break;
        case 21: _t->resetTotalScore(); break;
        case 22: _t->adjustScore((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->revealWord(); break;
        case 24: _t->reloadSettings(); break;
        case 25: _t->answerCorrect(); break;
        case 26: _t->answerIncorrect(); break;
        case 27: _t->answerSkipped(); break;
        case 28: _t->answerRevealed(); break;
        case 29: { int _r = _t->hintHideTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 30: { int _r = _t->resolveTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 31: { int _r = _t->scoreTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->moveLetterToUserAnswer((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->moveLetterToAnagram((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->resetAnagram(); break;
        case 35: _t->moveLetter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 36: { bool _r = _t->singlePlayerMode();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->checkWord();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KanagramGame::*)(const QString & )>(_a, &KanagramGame::fileError, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KanagramGame::*)()>(_a, &KanagramGame::dataLanguageChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KanagramGame::*)()>(_a, &KanagramGame::currentPlayerChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KanagramGame::*)()>(_a, &KanagramGame::singlePlayerChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KanagramGame::*)()>(_a, &KanagramGame::titleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KanagramGame::*)()>(_a, &KanagramGame::wordChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KanagramGame::*)()>(_a, &KanagramGame::scoreChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KanagramGame::*)()>(_a, &KanagramGame::userAnswerChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KanagramGame::*)()>(_a, &KanagramGame::useSoundsChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->anagram(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->word(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->hint(); break;
        case 3: *reinterpret_cast<QUrl*>(_v) = _t->picHint(); break;
        case 4: *reinterpret_cast<QUrl*>(_v) = _t->audioFile(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->userAnswer(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->documentTitle(); break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->vocabularyList(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->languageNames(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->dataLanguage(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->getPlayerNumber(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->singlePlayerMode(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->totalScore(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->totalScore2(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->useSounds(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 9: _t->setDataLanguage(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setPlayerNumber(*reinterpret_cast<int*>(_v)); break;
        case 11: _t->setSinglePlayerMode(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KanagramGame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KanagramGame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KanagramGameE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KanagramGame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 38;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void KanagramGame::fileError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KanagramGame::dataLanguageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KanagramGame::currentPlayerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KanagramGame::singlePlayerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KanagramGame::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KanagramGame::wordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KanagramGame::scoreChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KanagramGame::userAnswerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KanagramGame::useSoundsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
