/********************************************************************************
** Form generated from reading UI file 'vocabeditwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VOCABEDITWIDGET_H
#define UI_VOCABEDITWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_VocabEditWidget
{
public:
    QGridLayout *gridLayout;
    QGridLayout *gridLayout1;
    QHBoxLayout *hboxLayout;
    QPushButton *btnSave;
    QPushButton *btnClose;
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout2;
    QLabel *textLabel2;
    QLineEdit *txtVocabName;
    QLabel *textLabel1;
    QLineEdit *txtDescription;
    QHBoxLayout *hboxLayout1;
    QVBoxLayout *vboxLayout1;
    QPushButton *btnRemoveWord;
    QPushButton *btnNewWord;
    QListWidget *lboxWords;
    QGridLayout *gridLayout3;
    QLabel *textLabel3;
    QLineEdit *txtHint;
    QLineEdit *txtWord;
    QLabel *textLabel4;

    void setupUi(QDialog *VocabEditWidget)
    {
        if (VocabEditWidget->objectName().isEmpty())
            VocabEditWidget->setObjectName("VocabEditWidget");
        VocabEditWidget->resize(394, 369);
        gridLayout = new QGridLayout(VocabEditWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(6);
        gridLayout->setVerticalSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setHorizontalSpacing(6);
        gridLayout1->setVerticalSpacing(6);
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        btnSave = new QPushButton(VocabEditWidget);
        btnSave->setObjectName("btnSave");

        hboxLayout->addWidget(btnSave);

        btnClose = new QPushButton(VocabEditWidget);
        btnClose->setObjectName("btnClose");

        hboxLayout->addWidget(btnClose);


        gridLayout1->addLayout(hboxLayout, 1, 0, 1, 1);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout2 = new QGridLayout();
        gridLayout2->setObjectName("gridLayout2");
        gridLayout2->setHorizontalSpacing(6);
        gridLayout2->setVerticalSpacing(6);
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        textLabel2 = new QLabel(VocabEditWidget);
        textLabel2->setObjectName("textLabel2");

        gridLayout2->addWidget(textLabel2, 1, 0, 1, 1);

        txtVocabName = new QLineEdit(VocabEditWidget);
        txtVocabName->setObjectName("txtVocabName");

        gridLayout2->addWidget(txtVocabName, 0, 1, 1, 1);

        textLabel1 = new QLabel(VocabEditWidget);
        textLabel1->setObjectName("textLabel1");

        gridLayout2->addWidget(textLabel1, 0, 0, 1, 1);

        txtDescription = new QLineEdit(VocabEditWidget);
        txtDescription->setObjectName("txtDescription");

        gridLayout2->addWidget(txtDescription, 1, 1, 1, 1);


        vboxLayout->addLayout(gridLayout2);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        btnRemoveWord = new QPushButton(VocabEditWidget);
        btnRemoveWord->setObjectName("btnRemoveWord");

        vboxLayout1->addWidget(btnRemoveWord);

        btnNewWord = new QPushButton(VocabEditWidget);
        btnNewWord->setObjectName("btnNewWord");

        vboxLayout1->addWidget(btnNewWord);


        hboxLayout1->addLayout(vboxLayout1);

        lboxWords = new QListWidget(VocabEditWidget);
        lboxWords->setObjectName("lboxWords");

        hboxLayout1->addWidget(lboxWords);


        vboxLayout->addLayout(hboxLayout1);

        gridLayout3 = new QGridLayout();
        gridLayout3->setObjectName("gridLayout3");
        gridLayout3->setHorizontalSpacing(6);
        gridLayout3->setVerticalSpacing(6);
        gridLayout3->setContentsMargins(0, 0, 0, 0);
        textLabel3 = new QLabel(VocabEditWidget);
        textLabel3->setObjectName("textLabel3");

        gridLayout3->addWidget(textLabel3, 0, 0, 1, 1);

        txtHint = new QLineEdit(VocabEditWidget);
        txtHint->setObjectName("txtHint");

        gridLayout3->addWidget(txtHint, 1, 1, 1, 1);

        txtWord = new QLineEdit(VocabEditWidget);
        txtWord->setObjectName("txtWord");

        gridLayout3->addWidget(txtWord, 0, 1, 1, 1);

        textLabel4 = new QLabel(VocabEditWidget);
        textLabel4->setObjectName("textLabel4");

        gridLayout3->addWidget(textLabel4, 1, 0, 1, 1);


        vboxLayout->addLayout(gridLayout3);


        gridLayout1->addLayout(vboxLayout, 0, 0, 1, 1);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        textLabel2->setBuddy(txtDescription);
        textLabel1->setBuddy(txtVocabName);
        textLabel3->setBuddy(txtWord);
        textLabel4->setBuddy(txtHint);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(txtVocabName, txtDescription);
        QWidget::setTabOrder(txtDescription, btnRemoveWord);
        QWidget::setTabOrder(btnRemoveWord, btnNewWord);
        QWidget::setTabOrder(btnNewWord, txtWord);
        QWidget::setTabOrder(txtWord, txtHint);
        QWidget::setTabOrder(txtHint, btnSave);
        QWidget::setTabOrder(btnSave, btnClose);

        retranslateUi(VocabEditWidget);

        QMetaObject::connectSlotsByName(VocabEditWidget);
    } // setupUi

    void retranslateUi(QDialog *VocabEditWidget)
    {
        VocabEditWidget->setWindowTitle(tr2i18n("Vocabulary Editor", nullptr));
        btnSave->setText(tr2i18n("&Save", nullptr));
        btnClose->setText(tr2i18n("&Close", nullptr));
#if QT_CONFIG(whatsthis)
        textLabel2->setWhatsThis(tr2i18n("The description of the vocabulary. If you are creating a new vocabulary, add a description so that users of your vocabulary will know what kinds of words it contains.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel2->setText(tr2i18n("&Description:", nullptr));
#if QT_CONFIG(whatsthis)
        textLabel1->setWhatsThis(tr2i18n("The name of the vocabulary you are editing.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1->setText(tr2i18n("Vocabulary &name:", nullptr));
#if QT_CONFIG(whatsthis)
        btnRemoveWord->setWhatsThis(tr2i18n("Removes the selected word.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btnRemoveWord->setText(tr2i18n("&Remove Word", nullptr));
#if QT_CONFIG(whatsthis)
        btnNewWord->setWhatsThis(tr2i18n("Creates a new word.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btnNewWord->setText(tr2i18n("&New Word", nullptr));
#if QT_CONFIG(whatsthis)
        lboxWords->setWhatsThis(tr2i18n("The list of words in the vocabulary.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        textLabel3->setWhatsThis(tr2i18n("The selected word. This box allows you to edit the selected word.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel3->setText(tr2i18n("&Word:", nullptr));
#if QT_CONFIG(whatsthis)
        textLabel4->setWhatsThis(tr2i18n("The selected hint. Add a hint to aid in guessing the word.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel4->setText(tr2i18n("&Hint:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class VocabEditWidget: public Ui_VocabEditWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VOCABEDITWIDGET_H

